"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const graphql_binding_1 = require("graphql-binding");
const apollo_link_http_1 = require("apollo-link-http");
const graphql_tools_1 = require("graphql-tools");
const graphql_import_1 = require("graphql-import");
class BasicBinding extends graphql_binding_1.Binding {
    constructor({ endpoint, typeDefs }) {
        if (!typeDefs) {
            throw new Error("No `typeDefs` provided when calling `new BasicBinding()`");
        }
        if (typeof typeDefs === "string") {
            if (typeDefs.endsWith(".graphql")) {
                let path = require("path");
                let fs = require("fs");
                let schemaPath = path.resolve(typeDefs);
                if (!fs.existsSync(schemaPath)) {
                    throw new Error(`No schema found at: ${schemaPath}`);
                }
                typeDefs = graphql_import_1.importSchema(schemaPath);
            }
        }
        if (endpoint === undefined) {
            throw new Error("No endpoint found. Please provide the `endpoint` constructor option.");
        }
        if (!endpoint.startsWith("http")) {
            throw new Error(`Invalid endpoint provided: ${endpoint}`);
        }
        const fetch = require("node-fetch");
        const link = new apollo_link_http_1.HttpLink({ uri: endpoint, fetch });
        const schema = graphql_tools_1.makeRemoteExecutableSchema({ link, schema: typeDefs });
        super({
            schema: schema
        });
        this.schema = schema;
    }
}
exports.BasicBinding = BasicBinding;
var graphql_binding_2 = require("graphql-binding");
exports.forwardTo = graphql_binding_2.forwardTo;
//# sourceMappingURL=index.js.map